# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/stream/connection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..data import point_cloud_pb2 as blickfeld_dot_data_dot_point__cloud__pb2
from ..status import main_pb2 as blickfeld_dot_status_dot_main__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/stream/connection.proto',
  package='blickfeld.protocol.stream',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n!blickfeld/stream/connection.proto\x12\x19\x62lickfeld.protocol.stream\x1a\x17\x62lickfeld/options.proto\x1a blickfeld/data/point_cloud.proto\x1a\x1b\x62lickfeld/status/main.proto\"\x8e\x02\n\tSubscribe\x12\x46\n\x0bpoint_cloud\x18\x0b \x01(\x0b\x32/.blickfeld.protocol.stream.Subscribe.PointCloudH\x00\x12=\n\x06status\x18\x0c \x01(\x0b\x32+.blickfeld.protocol.stream.Subscribe.StatusH\x00\x12\x43\n\tdeveloper\x18\r \x01(\x0b\x32..blickfeld.protocol.stream.Subscribe.DeveloperH\x00\x1a\x0c\n\nPointCloud\x1a\x08\n\x06Status\x1a\x15\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02\x42\x06\n\x04\x64\x61ta\"\xd7\x01\n\x05\x45vent\x12:\n\x0bpoint_cloud\x18\x0b \x01(\x0b\x32#.blickfeld.protocol.data.PointCloudH\x00\x12,\n\x06status\x18\x0c \x01(\x0b\x32\x1a.blickfeld.protocol.StatusH\x00\x12?\n\tdeveloper\x18\r \x01(\x0b\x32*.blickfeld.protocol.stream.Event.DeveloperH\x00\x1a\x15\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02\x42\x0c\n\x04\x64\x61ta\x12\x04\xb0\xb5\x18\x01')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_data_dot_point__cloud__pb2.DESCRIPTOR,blickfeld_dot_status_dot_main__pb2.DESCRIPTOR,])




_SUBSCRIBE_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='blickfeld.protocol.stream.Subscribe.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=382,
)

_SUBSCRIBE_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.stream.Subscribe.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=392,
)

_SUBSCRIBE_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.stream.Subscribe.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=415,
)

_SUBSCRIBE = _descriptor.Descriptor(
  name='Subscribe',
  full_name='blickfeld.protocol.stream.Subscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='blickfeld.protocol.stream.Subscribe.point_cloud', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.stream.Subscribe.status', index=1,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.stream.Subscribe.developer', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBSCRIBE_POINTCLOUD, _SUBSCRIBE_STATUS, _SUBSCRIBE_DEVELOPER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.stream.Subscribe.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=153,
  serialized_end=423,
)


_EVENT_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.stream.Event.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=415,
)

_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='blickfeld.protocol.stream.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='blickfeld.protocol.stream.Event.point_cloud', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.stream.Event.status', index=1,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.stream.Event.developer', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EVENT_DEVELOPER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.stream.Event.data',
      index=0, containing_type=None, fields=[], serialized_options=_b('\260\265\030\001')),
  ],
  serialized_start=426,
  serialized_end=641,
)

_SUBSCRIBE_POINTCLOUD.containing_type = _SUBSCRIBE
_SUBSCRIBE_STATUS.containing_type = _SUBSCRIBE
_SUBSCRIBE_DEVELOPER.containing_type = _SUBSCRIBE
_SUBSCRIBE.fields_by_name['point_cloud'].message_type = _SUBSCRIBE_POINTCLOUD
_SUBSCRIBE.fields_by_name['status'].message_type = _SUBSCRIBE_STATUS
_SUBSCRIBE.fields_by_name['developer'].message_type = _SUBSCRIBE_DEVELOPER
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['point_cloud'])
_SUBSCRIBE.fields_by_name['point_cloud'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['status'])
_SUBSCRIBE.fields_by_name['status'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['developer'])
_SUBSCRIBE.fields_by_name['developer'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_EVENT_DEVELOPER.containing_type = _EVENT
_EVENT.fields_by_name['point_cloud'].message_type = blickfeld_dot_data_dot_point__cloud__pb2._POINTCLOUD
_EVENT.fields_by_name['status'].message_type = blickfeld_dot_status_dot_main__pb2._STATUS
_EVENT.fields_by_name['developer'].message_type = _EVENT_DEVELOPER
_EVENT.oneofs_by_name['data'].fields.append(
  _EVENT.fields_by_name['point_cloud'])
_EVENT.fields_by_name['point_cloud'].containing_oneof = _EVENT.oneofs_by_name['data']
_EVENT.oneofs_by_name['data'].fields.append(
  _EVENT.fields_by_name['status'])
_EVENT.fields_by_name['status'].containing_oneof = _EVENT.oneofs_by_name['data']
_EVENT.oneofs_by_name['data'].fields.append(
  _EVENT.fields_by_name['developer'])
_EVENT.fields_by_name['developer'].containing_oneof = _EVENT.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['Subscribe'] = _SUBSCRIBE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Subscribe = _reflection.GeneratedProtocolMessageType('Subscribe', (_message.Message,), dict(

  PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_POINTCLOUD,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.PointCloud)
    ))
  ,

  Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_STATUS,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.Status)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_DEVELOPER,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.Developer)
    ))
  ,
  DESCRIPTOR = _SUBSCRIBE,
  __module__ = 'blickfeld.stream.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe)
  ))
_sym_db.RegisterMessage(Subscribe)
_sym_db.RegisterMessage(Subscribe.PointCloud)
_sym_db.RegisterMessage(Subscribe.Status)
_sym_db.RegisterMessage(Subscribe.Developer)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _EVENT_DEVELOPER,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Event.Developer)
    ))
  ,
  DESCRIPTOR = _EVENT,
  __module__ = 'blickfeld.stream.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Event)
  ))
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.Developer)


_EVENT.oneofs_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)
