# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/frame.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from ..data import scanline_pb2 as blickfeld_dot_data_dot_scanline__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/frame.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1a\x62lickfeld/data/frame.proto\x12\x17\x62lickfeld.protocol.data\x1a#blickfeld/config/scan_pattern.proto\x1a\x1d\x62lickfeld/data/scanline.proto\"\xdf\x01\n\x05\x46rame\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x34\n\tscanlines\x18\x02 \x03(\x0b\x32!.blickfeld.protocol.data.Scanline\x12\x15\n\rstart_time_ns\x18\x03 \x01(\x04\x12<\n\x0cscan_pattern\x18\x05 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPattern\x12\x1e\n\x16total_number_of_points\x18\x06 \x01(\r\x12\x1f\n\x17total_number_of_returns\x18\x07 \x01(\r')
  ,
  dependencies=[blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_data_dot_scanline__pb2.DESCRIPTOR,])




_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='blickfeld.protocol.data.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.data.Frame.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanlines', full_name='blickfeld.protocol.data.Frame.scanlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_ns', full_name='blickfeld.protocol.data.Frame.start_time_ns', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='blickfeld.protocol.data.Frame.scan_pattern', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_number_of_points', full_name='blickfeld.protocol.data.Frame.total_number_of_points', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_number_of_returns', full_name='blickfeld.protocol.data.Frame.total_number_of_returns', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=347,
)

_FRAME.fields_by_name['scanlines'].message_type = blickfeld_dot_data_dot_scanline__pb2._SCANLINE
_FRAME.fields_by_name['scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), dict(
  DESCRIPTOR = _FRAME,
  __module__ = 'blickfeld.data.frame_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Frame)
  ))
_sym_db.RegisterMessage(Frame)


# @@protoc_insertion_point(module_scope)
