# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/scan_pattern.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/scan_pattern.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n#blickfeld/config/scan_pattern.proto\x12\x19\x62lickfeld.protocol.config\x1a\x17\x62lickfeld/options.proto\"\x9a\x07\n\x0bScanPattern\x12\x45\n\nhorizontal\x18\x01 \x01(\x0b\x32\x31.blickfeld.protocol.config.ScanPattern.Horizontal\x12\x41\n\x08vertical\x18\x02 \x01(\x0b\x32/.blickfeld.protocol.config.ScanPattern.Vertical\x12;\n\x05pulse\x18\x03 \x01(\x0b\x32,.blickfeld.protocol.config.ScanPattern.Pulse\x12\x44\n\nframe_rate\x18\x04 \x01(\x0b\x32\x30.blickfeld.protocol.config.ScanPattern.FrameRate\x1a\x19\n\nHorizontal\x12\x0b\n\x03\x66ov\x18\x01 \x01(\x02\x1ah\n\x08Vertical\x12\x0b\n\x03\x66ov\x18\x01 \x01(\x02\x12&\n\x0cscanlines_up\x18\x02 \x01(\r:\x03\x32\x30\x30\x42\x0b\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x12\'\n\x0escanlines_down\x18\x03 \x01(\r:\x02\x33\x30\x42\x0b\x81\xb5\x18\x00\x00\x00\x00\x00\x00\xf0?\x1a\x90\x03\n\x05Pulse\x12\x15\n\rangle_spacing\x18\x02 \x01(\x02\x12V\n\x04type\x18\x03 \x01(\x0e\x32\x31.blickfeld.protocol.config.ScanPattern.Pulse.Type:\x15\x45QUI_HORIZONTAL_ANGLE\x12S\n\nframe_mode\x18\x04 \x01(\x0e\x32\x36.blickfeld.protocol.config.ScanPattern.Pulse.FrameMode:\x07ONLY_UP\x12#\n\x15\x64istortion_correction\x18\x05 \x01(\x08:\x04true\"3\n\x04Type\x12\x19\n\x15\x45QUI_HORIZONTAL_ANGLE\x10\x00\x12\x10\n\x0c\x45QUI_DENSITY\x10\x01\"T\n\tFrameMode\x12\x08\n\x04NONE\x10\x00\x12\x13\n\x0f\x43OMBINE_UP_DOWN\x10\x01\x12\x0b\n\x07ONLY_UP\x10\x02\x12\r\n\tONLY_DOWN\x10\x03\x12\x0c\n\x08SEPARATE\x10\x04*\x04\x08\x01\x10\x02*\x04\x08\x06\x10\x07R\x07padding\x1aZ\n\tFrameRate\x12\x14\n\x06target\x18\x01 \x01(\x01\x42\x04\xb0\xb5\x18\x01\x12\x15\n\x07maximum\x18\x02 \x01(\x01\x42\x04\xb0\xb5\x18\x01\x12 \n\x15reference_time_offset\x18\x03 \x01(\x01:\x01\x30*\x04\x08\x05\x10\x06*\x04\x08\x06\x10\x07')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])



_SCANPATTERN_PULSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUI_HORIZONTAL_ANGLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUI_DENSITY', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=752,
  serialized_end=803,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_TYPE)

_SCANPATTERN_PULSE_FRAMEMODE = _descriptor.EnumDescriptor(
  name='FrameMode',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse.FrameMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMBINE_UP_DOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLY_UP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLY_DOWN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEPARATE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=805,
  serialized_end=889,
)
_sym_db.RegisterEnumDescriptor(_SCANPATTERN_PULSE_FRAMEMODE)


_SCANPATTERN_HORIZONTAL = _descriptor.Descriptor(
  name='Horizontal',
  full_name='blickfeld.protocol.config.ScanPattern.Horizontal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='blickfeld.protocol.config.ScanPattern.Horizontal.fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=401,
)

_SCANPATTERN_VERTICAL = _descriptor.Descriptor(
  name='Vertical',
  full_name='blickfeld.protocol.config.ScanPattern.Vertical',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='blickfeld.protocol.config.ScanPattern.Vertical.fov', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanlines_up', full_name='blickfeld.protocol.config.ScanPattern.Vertical.scanlines_up', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=200,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\201\265\030\000\000\000\000\000\000\360?'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanlines_down', full_name='blickfeld.protocol.config.ScanPattern.Vertical.scanlines_down', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=30,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\201\265\030\000\000\000\000\000\000\360?'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=507,
)

_SCANPATTERN_PULSE = _descriptor.Descriptor(
  name='Pulse',
  full_name='blickfeld.protocol.config.ScanPattern.Pulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle_spacing', full_name='blickfeld.protocol.config.ScanPattern.Pulse.angle_spacing', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='blickfeld.protocol.config.ScanPattern.Pulse.type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_mode', full_name='blickfeld.protocol.config.ScanPattern.Pulse.frame_mode', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distortion_correction', full_name='blickfeld.protocol.config.ScanPattern.Pulse.distortion_correction', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCANPATTERN_PULSE_TYPE,
    _SCANPATTERN_PULSE_FRAMEMODE,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 2), (6, 7), ],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=910,
)

_SCANPATTERN_FRAMERATE = _descriptor.Descriptor(
  name='FrameRate',
  full_name='blickfeld.protocol.config.ScanPattern.FrameRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.target', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.maximum', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_time_offset', full_name='blickfeld.protocol.config.ScanPattern.FrameRate.reference_time_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=1002,
)

_SCANPATTERN = _descriptor.Descriptor(
  name='ScanPattern',
  full_name='blickfeld.protocol.config.ScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal', full_name='blickfeld.protocol.config.ScanPattern.horizontal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical', full_name='blickfeld.protocol.config.ScanPattern.vertical', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pulse', full_name='blickfeld.protocol.config.ScanPattern.pulse', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_rate', full_name='blickfeld.protocol.config.ScanPattern.frame_rate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SCANPATTERN_HORIZONTAL, _SCANPATTERN_VERTICAL, _SCANPATTERN_PULSE, _SCANPATTERN_FRAMERATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(5, 6), (6, 7), ],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=1014,
)

_SCANPATTERN_HORIZONTAL.containing_type = _SCANPATTERN
_SCANPATTERN_VERTICAL.containing_type = _SCANPATTERN
_SCANPATTERN_PULSE.fields_by_name['type'].enum_type = _SCANPATTERN_PULSE_TYPE
_SCANPATTERN_PULSE.fields_by_name['frame_mode'].enum_type = _SCANPATTERN_PULSE_FRAMEMODE
_SCANPATTERN_PULSE.containing_type = _SCANPATTERN
_SCANPATTERN_PULSE_TYPE.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_PULSE_FRAMEMODE.containing_type = _SCANPATTERN_PULSE
_SCANPATTERN_FRAMERATE.containing_type = _SCANPATTERN
_SCANPATTERN.fields_by_name['horizontal'].message_type = _SCANPATTERN_HORIZONTAL
_SCANPATTERN.fields_by_name['vertical'].message_type = _SCANPATTERN_VERTICAL
_SCANPATTERN.fields_by_name['pulse'].message_type = _SCANPATTERN_PULSE
_SCANPATTERN.fields_by_name['frame_rate'].message_type = _SCANPATTERN_FRAMERATE
DESCRIPTOR.message_types_by_name['ScanPattern'] = _SCANPATTERN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanPattern = _reflection.GeneratedProtocolMessageType('ScanPattern', (_message.Message,), dict(

  Horizontal = _reflection.GeneratedProtocolMessageType('Horizontal', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_HORIZONTAL,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Horizontal)
    ))
  ,

  Vertical = _reflection.GeneratedProtocolMessageType('Vertical', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_VERTICAL,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Vertical)
    ))
  ,

  Pulse = _reflection.GeneratedProtocolMessageType('Pulse', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_PULSE,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.Pulse)
    ))
  ,

  FrameRate = _reflection.GeneratedProtocolMessageType('FrameRate', (_message.Message,), dict(
    DESCRIPTOR = _SCANPATTERN_FRAMERATE,
    __module__ = 'blickfeld.config.scan_pattern_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern.FrameRate)
    ))
  ,
  DESCRIPTOR = _SCANPATTERN,
  __module__ = 'blickfeld.config.scan_pattern_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.ScanPattern)
  ))
_sym_db.RegisterMessage(ScanPattern)
_sym_db.RegisterMessage(ScanPattern.Horizontal)
_sym_db.RegisterMessage(ScanPattern.Vertical)
_sym_db.RegisterMessage(ScanPattern.Pulse)
_sym_db.RegisterMessage(ScanPattern.FrameRate)


_SCANPATTERN_VERTICAL.fields_by_name['scanlines_up']._options = None
_SCANPATTERN_VERTICAL.fields_by_name['scanlines_down']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['target']._options = None
_SCANPATTERN_FRAMERATE.fields_by_name['maximum']._options = None
# @@protoc_insertion_point(module_scope)
