# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/connection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as blickfeld_dot_options__pb2
from . import error_pb2 as blickfeld_dot_error__pb2
from .config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from .stream import connection_pb2 as blickfeld_dot_stream_dot_connection__pb2
from .status import main_pb2 as blickfeld_dot_status_dot_main__pb2
from .config import secure_pb2 as blickfeld_dot_config_dot_secure__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/connection.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1a\x62lickfeld/connection.proto\x12\x12\x62lickfeld.protocol\x1a\x17\x62lickfeld/options.proto\x1a\x15\x62lickfeld/error.proto\x1a#blickfeld/config/scan_pattern.proto\x1a!blickfeld/stream/connection.proto\x1a\x1b\x62lickfeld/status/main.proto\x1a\x1d\x62lickfeld/config/secure.proto\"\xc9\x07\n\x07Request\x12\x32\n\x05hello\x18\x0b \x01(\x0b\x32!.blickfeld.protocol.Request.HelloH\x00\x12:\n\tdeveloper\x18\r \x01(\x0b\x32%.blickfeld.protocol.Request.DeveloperH\x00\x12\x46\n\x10set_scan_pattern\x18\x0f \x01(\x0b\x32*.blickfeld.protocol.Request.SetScanPatternH\x00\x12H\n\x11\x66ill_scan_pattern\x18\x10 \x01(\x0b\x32+.blickfeld.protocol.Request.FillScanPatternH\x00\x12\x46\n\x10get_scan_pattern\x18\x11 \x01(\x0b\x32*.blickfeld.protocol.Request.GetScanPatternH\x00\x12\x39\n\tsubscribe\x18\x12 \x01(\x0b\x32$.blickfeld.protocol.stream.SubscribeH\x00\x12\x34\n\x06status\x18\x13 \x01(\x0b\x32\".blickfeld.protocol.Request.StatusH\x00\x12\x11\n\x07_asJSON\x18\x64 \x01(\tH\x00\x12;\n\raccept_format\x18\x65 \x01(\x0e\x32\x1a.blickfeld.protocol.Format:\x08PROTOBUF\x1a!\n\x05Hello\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x1a\x1f\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02:\x08\x92\xa6\x1d\x04\x08\x01\x10\x00\x1a\xab\x01\n\x0eSetScanPattern\x12<\n\x06\x63onfig\x18\x03 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xd0\xb5\x18\x01\x12\x16\n\x07persist\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x43\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01\x1a\x9c\x01\n\x0f\x46illScanPattern\x12@\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x08\xb8\xb5\x18\x01\xd0\xb5\x18\x01\x12G\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x08\xb8\xb5\x18\x01\xb0\xb5\x18\x01\x1a\x10\n\x0eGetScanPattern\x1a\x08\n\x06StatusB\x06\n\x04\x64\x61ta\"\x98\x07\n\x08Response\x12\x14\n\x0ctimestamp_ns\x18\x01 \x01(\x04\x12*\n\x05\x65rror\x18\n \x01(\x0b\x32\x19.blickfeld.protocol.ErrorH\x00\x12\x33\n\x05hello\x18\x0b \x01(\x0b\x32\".blickfeld.protocol.Response.HelloH\x00\x12;\n\tdeveloper\x18\r \x01(\x0b\x32&.blickfeld.protocol.Response.DeveloperH\x00\x12G\n\x10set_scan_pattern\x18\x0f \x01(\x0b\x32+.blickfeld.protocol.Response.SetScanPatternH\x00\x12I\n\x11\x66ill_scan_pattern\x18\x10 \x01(\x0b\x32,.blickfeld.protocol.Response.FillScanPatternH\x00\x12G\n\x10get_scan_pattern\x18\x11 \x01(\x0b\x32+.blickfeld.protocol.Response.GetScanPatternH\x00\x12\x31\n\x05\x65vent\x18\x12 \x01(\x0b\x32 .blickfeld.protocol.stream.EventH\x00\x12,\n\x06status\x18\x13 \x01(\x0b\x32\x1a.blickfeld.protocol.StatusH\x00\x12\x11\n\x07_asJSON\x18\x64 \x01(\tH\x00\x1a!\n\x05Hello\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x1a\x15\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02\x1a\x10\n\x0eSetScanPattern\x1a\x9c\x01\n\x0f\x46illScanPattern\x12<\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xd0\xb5\x18\x01\x12\x43\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01:\x06\x8a\xa6\x1d\x02..\x1a\x93\x01\n\x0eGetScanPattern\x12<\n\x06\x63onfig\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xd0\xb5\x18\x01\x12\x43\n\rlegacy_config\x18\x01 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01\x42\x06\n\x04\x64\x61ta* \n\x06\x46ormat\x12\x0c\n\x08PROTOBUF\x10\x01\x12\x08\n\x04JSON\x10\x02')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_error__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_stream_dot_connection__pb2.DESCRIPTOR,blickfeld_dot_status_dot_main__pb2.DESCRIPTOR,blickfeld_dot_config_dot_secure__pb2.DESCRIPTOR,])

_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='blickfeld.protocol.Format',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2125,
  serialized_end=2157,
)
_sym_db.RegisterEnumDescriptor(_FORMAT)

Format = enum_type_wrapper.EnumTypeWrapper(_FORMAT)
PROTOBUF = 1
JSON = 2



_REQUEST_HELLO = _descriptor.Descriptor(
  name='Hello',
  full_name='blickfeld.protocol.Request.Hello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='blickfeld.protocol.Request.Hello.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=798,
)

_REQUEST_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.Request.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\222\246\035\004\010\001\020\000'),
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=831,
)

_REQUEST_SETSCANPATTERN = _descriptor.Descriptor(
  name='SetScanPattern',
  full_name='blickfeld.protocol.Request.SetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Request.SetScanPattern.config', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persist', full_name='blickfeld.protocol.Request.SetScanPattern.persist', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Request.SetScanPattern.legacy_config', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=1005,
)

_REQUEST_FILLSCANPATTERN = _descriptor.Descriptor(
  name='FillScanPattern',
  full_name='blickfeld.protocol.Request.FillScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Request.FillScanPattern.config', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\270\265\030\001\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Request.FillScanPattern.legacy_config', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\270\265\030\001\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1164,
)

_REQUEST_GETSCANPATTERN = _descriptor.Descriptor(
  name='GetScanPattern',
  full_name='blickfeld.protocol.Request.GetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1166,
  serialized_end=1182,
)

_REQUEST_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.Request.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1192,
)

_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='blickfeld.protocol.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hello', full_name='blickfeld.protocol.Request.hello', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.Request.developer', index=1,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_scan_pattern', full_name='blickfeld.protocol.Request.set_scan_pattern', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_scan_pattern', full_name='blickfeld.protocol.Request.fill_scan_pattern', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_scan_pattern', full_name='blickfeld.protocol.Request.get_scan_pattern', index=4,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribe', full_name='blickfeld.protocol.Request.subscribe', index=5,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.Request.status', index=6,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='_asJSON', full_name='blickfeld.protocol.Request._asJSON', index=7,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accept_format', full_name='blickfeld.protocol.Request.accept_format', index=8,
      number=101, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REQUEST_HELLO, _REQUEST_DEVELOPER, _REQUEST_SETSCANPATTERN, _REQUEST_FILLSCANPATTERN, _REQUEST_GETSCANPATTERN, _REQUEST_STATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.Request.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=231,
  serialized_end=1200,
)


_RESPONSE_HELLO = _descriptor.Descriptor(
  name='Hello',
  full_name='blickfeld.protocol.Response.Hello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='blickfeld.protocol.Response.Hello.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=798,
)

_RESPONSE_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.Response.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=821,
)

_RESPONSE_SETSCANPATTERN = _descriptor.Descriptor(
  name='SetScanPattern',
  full_name='blickfeld.protocol.Response.SetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=850,
)

_RESPONSE_FILLSCANPATTERN = _descriptor.Descriptor(
  name='FillScanPattern',
  full_name='blickfeld.protocol.Response.FillScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Response.FillScanPattern.config', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Response.FillScanPattern.legacy_config', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\212\246\035\002..'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1965,
)

_RESPONSE_GETSCANPATTERN = _descriptor.Descriptor(
  name='GetScanPattern',
  full_name='blickfeld.protocol.Response.GetScanPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='blickfeld.protocol.Response.GetScanPattern.config', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_config', full_name='blickfeld.protocol.Response.GetScanPattern.legacy_config', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2115,
)

_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='blickfeld.protocol.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_ns', full_name='blickfeld.protocol.Response.timestamp_ns', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='blickfeld.protocol.Response.error', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hello', full_name='blickfeld.protocol.Response.hello', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.Response.developer', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_scan_pattern', full_name='blickfeld.protocol.Response.set_scan_pattern', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_scan_pattern', full_name='blickfeld.protocol.Response.fill_scan_pattern', index=5,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_scan_pattern', full_name='blickfeld.protocol.Response.get_scan_pattern', index=6,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='blickfeld.protocol.Response.event', index=7,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.Response.status', index=8,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='_asJSON', full_name='blickfeld.protocol.Response._asJSON', index=9,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESPONSE_HELLO, _RESPONSE_DEVELOPER, _RESPONSE_SETSCANPATTERN, _RESPONSE_FILLSCANPATTERN, _RESPONSE_GETSCANPATTERN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.Response.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1203,
  serialized_end=2123,
)

_REQUEST_HELLO.containing_type = _REQUEST
_REQUEST_DEVELOPER.containing_type = _REQUEST
_REQUEST_SETSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_SETSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_SETSCANPATTERN.containing_type = _REQUEST
_REQUEST_FILLSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_FILLSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_REQUEST_FILLSCANPATTERN.containing_type = _REQUEST
_REQUEST_GETSCANPATTERN.containing_type = _REQUEST
_REQUEST_STATUS.containing_type = _REQUEST
_REQUEST.fields_by_name['hello'].message_type = _REQUEST_HELLO
_REQUEST.fields_by_name['developer'].message_type = _REQUEST_DEVELOPER
_REQUEST.fields_by_name['set_scan_pattern'].message_type = _REQUEST_SETSCANPATTERN
_REQUEST.fields_by_name['fill_scan_pattern'].message_type = _REQUEST_FILLSCANPATTERN
_REQUEST.fields_by_name['get_scan_pattern'].message_type = _REQUEST_GETSCANPATTERN
_REQUEST.fields_by_name['subscribe'].message_type = blickfeld_dot_stream_dot_connection__pb2._SUBSCRIBE
_REQUEST.fields_by_name['status'].message_type = _REQUEST_STATUS
_REQUEST.fields_by_name['accept_format'].enum_type = _FORMAT
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['hello'])
_REQUEST.fields_by_name['hello'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['developer'])
_REQUEST.fields_by_name['developer'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['set_scan_pattern'])
_REQUEST.fields_by_name['set_scan_pattern'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['fill_scan_pattern'])
_REQUEST.fields_by_name['fill_scan_pattern'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['get_scan_pattern'])
_REQUEST.fields_by_name['get_scan_pattern'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['subscribe'])
_REQUEST.fields_by_name['subscribe'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['status'])
_REQUEST.fields_by_name['status'].containing_oneof = _REQUEST.oneofs_by_name['data']
_REQUEST.oneofs_by_name['data'].fields.append(
  _REQUEST.fields_by_name['_asJSON'])
_REQUEST.fields_by_name['_asJSON'].containing_oneof = _REQUEST.oneofs_by_name['data']
_RESPONSE_HELLO.containing_type = _RESPONSE
_RESPONSE_DEVELOPER.containing_type = _RESPONSE
_RESPONSE_SETSCANPATTERN.containing_type = _RESPONSE
_RESPONSE_FILLSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_FILLSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_FILLSCANPATTERN.containing_type = _RESPONSE
_RESPONSE_GETSCANPATTERN.fields_by_name['config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_GETSCANPATTERN.fields_by_name['legacy_config'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_RESPONSE_GETSCANPATTERN.containing_type = _RESPONSE
_RESPONSE.fields_by_name['error'].message_type = blickfeld_dot_error__pb2._ERROR
_RESPONSE.fields_by_name['hello'].message_type = _RESPONSE_HELLO
_RESPONSE.fields_by_name['developer'].message_type = _RESPONSE_DEVELOPER
_RESPONSE.fields_by_name['set_scan_pattern'].message_type = _RESPONSE_SETSCANPATTERN
_RESPONSE.fields_by_name['fill_scan_pattern'].message_type = _RESPONSE_FILLSCANPATTERN
_RESPONSE.fields_by_name['get_scan_pattern'].message_type = _RESPONSE_GETSCANPATTERN
_RESPONSE.fields_by_name['event'].message_type = blickfeld_dot_stream_dot_connection__pb2._EVENT
_RESPONSE.fields_by_name['status'].message_type = blickfeld_dot_status_dot_main__pb2._STATUS
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['error'])
_RESPONSE.fields_by_name['error'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['hello'])
_RESPONSE.fields_by_name['hello'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['developer'])
_RESPONSE.fields_by_name['developer'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['set_scan_pattern'])
_RESPONSE.fields_by_name['set_scan_pattern'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['fill_scan_pattern'])
_RESPONSE.fields_by_name['fill_scan_pattern'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['get_scan_pattern'])
_RESPONSE.fields_by_name['get_scan_pattern'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['event'])
_RESPONSE.fields_by_name['event'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['status'])
_RESPONSE.fields_by_name['status'].containing_oneof = _RESPONSE.oneofs_by_name['data']
_RESPONSE.oneofs_by_name['data'].fields.append(
  _RESPONSE.fields_by_name['_asJSON'])
_RESPONSE.fields_by_name['_asJSON'].containing_oneof = _RESPONSE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.enum_types_by_name['Format'] = _FORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), dict(

  Hello = _reflection.GeneratedProtocolMessageType('Hello', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_HELLO,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.Hello)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_DEVELOPER,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.Developer)
    ))
  ,

  SetScanPattern = _reflection.GeneratedProtocolMessageType('SetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_SETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.SetScanPattern)
    ))
  ,

  FillScanPattern = _reflection.GeneratedProtocolMessageType('FillScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_FILLSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.FillScanPattern)
    ))
  ,

  GetScanPattern = _reflection.GeneratedProtocolMessageType('GetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_GETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.GetScanPattern)
    ))
  ,

  Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
    DESCRIPTOR = _REQUEST_STATUS,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request.Status)
    ))
  ,
  DESCRIPTOR = _REQUEST,
  __module__ = 'blickfeld.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Request)
  ))
_sym_db.RegisterMessage(Request)
_sym_db.RegisterMessage(Request.Hello)
_sym_db.RegisterMessage(Request.Developer)
_sym_db.RegisterMessage(Request.SetScanPattern)
_sym_db.RegisterMessage(Request.FillScanPattern)
_sym_db.RegisterMessage(Request.GetScanPattern)
_sym_db.RegisterMessage(Request.Status)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(

  Hello = _reflection.GeneratedProtocolMessageType('Hello', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_HELLO,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.Hello)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_DEVELOPER,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.Developer)
    ))
  ,

  SetScanPattern = _reflection.GeneratedProtocolMessageType('SetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_SETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.SetScanPattern)
    ))
  ,

  FillScanPattern = _reflection.GeneratedProtocolMessageType('FillScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_FILLSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.FillScanPattern)
    ))
  ,

  GetScanPattern = _reflection.GeneratedProtocolMessageType('GetScanPattern', (_message.Message,), dict(
    DESCRIPTOR = _RESPONSE_GETSCANPATTERN,
    __module__ = 'blickfeld.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response.GetScanPattern)
    ))
  ,
  DESCRIPTOR = _RESPONSE,
  __module__ = 'blickfeld.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Response)
  ))
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Hello)
_sym_db.RegisterMessage(Response.Developer)
_sym_db.RegisterMessage(Response.SetScanPattern)
_sym_db.RegisterMessage(Response.FillScanPattern)
_sym_db.RegisterMessage(Response.GetScanPattern)


_REQUEST_DEVELOPER._options = None
_REQUEST_SETSCANPATTERN.fields_by_name['config']._options = None
_REQUEST_SETSCANPATTERN.fields_by_name['legacy_config']._options = None
_REQUEST_FILLSCANPATTERN.fields_by_name['config']._options = None
_REQUEST_FILLSCANPATTERN.fields_by_name['legacy_config']._options = None
_RESPONSE_FILLSCANPATTERN.fields_by_name['config']._options = None
_RESPONSE_FILLSCANPATTERN.fields_by_name['legacy_config']._options = None
_RESPONSE_FILLSCANPATTERN._options = None
_RESPONSE_GETSCANPATTERN.fields_by_name['config']._options = None
_RESPONSE_GETSCANPATTERN.fields_by_name['legacy_config']._options = None
# @@protoc_insertion_point(module_scope)
